@@ -66,25 +66,20 @@ struct ImporterPrivate
 
     QUrl mCurrentUrl;
 
-    void emitError(const QString& message)
-    {
-        QMetaObject::invokeMethod(q, "error", Q_ARG(QString, message));
-    }
-
     bool createImportDir(const QUrl& url)
     {
         Q_ASSERT(url.isLocalFile());
         // FIXME: Support remote urls
 
         if (!QDir().mkpath(url.toLocalFile())) {
-            emitError(i18n("Could not create destination folder."));
+            emit q->error(i18n("Could not create destination folder."));
             return false;
         }
         QString message;
         QString dir = FileUtils::createTempDir(url.toLocalFile(), ".gwenview_importer-", &message);
         mTempImportDirUrl = QUrl::fromLocalFile(dir);
         if (mTempImportDirUrl.isEmpty()) {
-            emitError(i18n("Could not create temporary upload folder:\n%1", message));
+            emit q->error(i18n("Could not create temporary upload folder:\n%1", message));
             return false;
         }
         return true;
@@ -177,7 +172,7 @@ void Importer::start(const QList<QUrl>& list, const QUrl& destination)
     d->mJobProgress = 0;
 
     emitProgressChanged();
-    maximumChanged(d->mUrlList.count() * 100);
+    emit maximumChanged(d->mUrlList.count() * 100);
 
     if (!d->createImportDir(destination)) {
         qWarning() << "Could not create import dir";
@@ -204,7 +199,7 @@ void Importer::finalizeImport()
 {
     KIO::Job* job = KIO::del(d->mTempImportDirUrl, KIO::HideProgressInfo);
     KJobWidgets::setWindow(job, d->mAuthWindow);
-    importFinished();
+    emit importFinished();
 }
 
 void Importer::advance()
@@ -222,7 +217,7 @@ void Importer::slotPercent(KJob*, unsigned long percent)
 
 void Importer::emitProgressChanged()
 {
-    progressChanged(d->mProgress * 100 + d->mJobProgress);
+    emit progressChanged(d->mProgress * 100 + d->mJobProgress);
 }
 
 QList<QUrl> Importer::importedUrlList() const
