@@ -35,7 +35,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 #include <lib/documentview/rasterimageview.h>
 #include <QFontDatabase>
 #include "croptool.h"
-#include "signalblocker.h"
 #include "ui_cropwidget.h"
 #include "cropwidget.h"
 
@@ -86,7 +85,7 @@ struct CropWidgetPrivate : public Ui_CropWidget
 
         // A custom ratio has been entered, extract ratio from the text
         // If invalid, return zero size instead
-        const QStringList lst = ratioComboBox->currentText().split(':');
+        const QStringList lst = ratioComboBox->currentText().split(QLatin1Char(':'));
         if (lst.size() != 2) {
             return QSizeF(0, 0);
         }
@@ -123,7 +122,7 @@ struct CropWidgetPrivate : public Ui_CropWidget
         }
 
         // Size must be custom ratio, convert to text and add to combobox
-        QString ratioString = QString("%1:%2").arg(size.width()).arg(size.height());
+        QString ratioString = QStringLiteral("%1:%2").arg(size.width()).arg(size.height());
         ratioComboBox->setCurrentText(ratioString);
     }
 
@@ -148,7 +147,7 @@ struct CropWidgetPrivate : public Ui_CropWidget
     void addRatioToComboBox(const QSizeF& size, const QString& label = QString())
     {
         QString text = label.isEmpty()
-            ? QString("%1:%2").arg(size.width()).arg(size.height())
+            ? QStringLiteral("%1:%2").arg(size.width()).arg(size.height())
             : label;
         ratioComboBox->addItem(text, QVariant(size));
     }
@@ -207,7 +206,7 @@ struct CropWidgetPrivate : public Ui_CropWidget
         Q_ASSERT(edit);
         // Do not use i18n("%1:%2") because ':' should not be translated, it is
         // used to parse the ratio string.
-        edit->setPlaceholderText(QString("%1:%2").arg(i18n("Width")).arg(i18n("Height")));
+        edit->setPlaceholderText(QStringLiteral("%1:%2").arg(i18n("Width"), i18n("Height")));
 
         // Enable clear button
         edit->setClearButtonEnabled(true);
@@ -252,7 +251,7 @@ struct CropWidgetPrivate : public Ui_CropWidget
     void initDialogButtonBox()
     {
         QPushButton* cropButton = dialogButtonBox->button(QDialogButtonBox::Ok);
-        cropButton->setIcon(QIcon::fromTheme("transform-crop-and-resize"));
+        cropButton->setIcon(QIcon::fromTheme(QStringLiteral("transform-crop-and-resize")));
         cropButton->setText(i18n("Crop"));
 
         QObject::connect(dialogButtonBox, &QDialogButtonBox::accepted, q, &CropWidget::cropRequested);
@@ -283,10 +282,10 @@ CropWidget::CropWidget(QWidget* parent, RasterImageView* imageView, CropTool* cr
 
     connect(d->mCropTool, &CropTool::rectUpdated, this, &CropWidget::setCropRect);
 
-    connect(d->leftSpinBox, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &CropWidget::slotPositionChanged);
-    connect(d->topSpinBox, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &CropWidget::slotPositionChanged);
-    connect(d->widthSpinBox, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &CropWidget::slotWidthChanged);
-    connect(d->heightSpinBox, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &CropWidget::slotHeightChanged);
+    connect(d->leftSpinBox, QOverload<int>::of(&QSpinBox::valueChanged), this, &CropWidget::slotPositionChanged);
+    connect(d->topSpinBox, QOverload<int>::of(&QSpinBox::valueChanged), this, &CropWidget::slotPositionChanged);
+    connect(d->widthSpinBox, QOverload<int>::of(&QSpinBox::valueChanged), this, &CropWidget::slotWidthChanged);
+    connect(d->heightSpinBox, QOverload<int>::of(&QSpinBox::valueChanged), this, &CropWidget::slotHeightChanged);
 
     d->initDialogButtonBox();
 
@@ -295,7 +294,7 @@ CropWidget::CropWidget(QWidget* parent, RasterImageView* imageView, CropTool* cr
     // Index Changed: required so that choosing an item with the same text is detected (e.g. going from US Letter portrait
     // to US Letter landscape)
     connect(d->ratioComboBox, &QComboBox::editTextChanged, this, &CropWidget::slotRatioComboBoxChanged);
-    connect(d->ratioComboBox, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &CropWidget::slotRatioComboBoxChanged);
+    connect(d->ratioComboBox, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &CropWidget::slotRatioComboBoxChanged);
 
     // Don't do this before signals are connected, otherwise the tool won't get
     // initialized
