@@ -22,7 +22,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 // Qt
 #include <QPointer>
-#include <QPointer>
 #include <QFrame>
 
 #include <lib/gwenviewlib_export.h>
@@ -54,9 +53,9 @@ public:
      */
     void setContent(QWidget* content);
 
-    QSize sizeHint() const Q_DECL_OVERRIDE;
+    QSize sizeHint() const override;
 
-    QSize minimumSizeHint() const Q_DECL_OVERRIDE;
+    QSize minimumSizeHint() const override;
 
     int slideHeight() const;
 
@@ -80,8 +79,8 @@ Q_SIGNALS:
     void slidedOut();
 
 protected:
-    void resizeEvent(QResizeEvent*) Q_DECL_OVERRIDE;
-    bool eventFilter(QObject*, QEvent* event) Q_DECL_OVERRIDE;
+    void resizeEvent(QResizeEvent*) override;
+    bool eventFilter(QObject*, QEvent* event) override;
 
 private Q_SLOTS:
     void slotAnimFinished();
