@@ -65,7 +65,7 @@ bool ThumbnailContext::load(const QString &pixPath, int pixelSize)
     QImage originalImage;
     QSize originalSize;
 
-    QByteArray formatHint = pixPath.section('.', -1).toLocal8Bit().toLower();
+    QByteArray formatHint = pixPath.section(QLatin1Char('.'), -1).toLocal8Bit().toLower();
     QImageReader reader(pixPath);
 
     JpegContent content;
@@ -76,14 +76,14 @@ bool ThumbnailContext::load(const QString &pixPath, int pixelSize)
 
 #ifdef KDCRAW_FOUND
     // raw images deserve special treatment
-    if (KDcrawIface::KDcraw::rawFilesList().contains(QString(formatHint))) {
+    if (KDcrawIface::KDcraw::rawFilesList().contains(QString::fromLatin1(formatHint))) {
         // use KDCraw to extract the preview
         bool ret = KDcrawIface::KDcraw::loadEmbeddedPreview(data, pixPath);
 
         // We need QImage. Loading JpegContent from QImage - exif lost
         // Loading QImage from JpegContent - unimplemented, would go with loadFromData
         if (!ret || !originalImage.loadFromData(data) || qMin(originalImage.width(), originalImage.height()) < MIN_PREV_SIZE) {
-            // if the emebedded preview loading failed or gets just a small image, load
+            // if the embedded preview loading failed or gets just a small image, load
             // half preview instead. That's slower...
             if (!KDcrawIface::KDcraw::loadHalfPreview(data, pixPath)) {
                 qWarning() << "unable to get preview for " << pixPath.toUtf8().constData();
@@ -149,6 +149,11 @@ bool ThumbnailContext::load(const QString &pixPath, int pixelSize)
         }
     }
 
+    // Rotate if necessary
+    if (GwenviewConfig::applyExifOrientation()) {
+        reader.setAutoTransform(true);
+    }
+
     // format() is empty after QImageReader::read() is called
     format = reader.format();
     if (!reader.read(&originalImage)) {
@@ -168,22 +173,10 @@ bool ThumbnailContext::load(const QString &pixPath, int pixelSize)
         mImage = originalImage.scaled(pixelSize, pixelSize, Qt::KeepAspectRatio);
     }
 
-    // Rotate if necessary
-    if (orientation != NORMAL && orientation != NOT_AVAILABLE && GwenviewConfig::applyExifOrientation()) {
-        QMatrix matrix = ImageUtils::transformMatrix(orientation);
-        mImage = mImage.transformed(matrix);
-
-        switch (orientation) {
-        case TRANSPOSE:
-        case ROT_90:
-        case TRANSVERSE:
-        case ROT_270:
-            qSwap(mOriginalWidth, mOriginalHeight);
-            break;
-        default:
-            break;
-        }
+    if (reader.autoTransform() && (reader.transformation() & QImageIOHandler::TransformationRotate90)) {
+        qSwap(mOriginalWidth, mOriginalHeight);
     }
+
     return true;
 }
 
@@ -299,7 +292,7 @@ void ThumbnailGenerator::run()
             QSize size(mOriginalWidth, mOriginalHeight);
             LOG("emitting done signal, size=" << size);
             QMutexLocker lock(&mMutex);
-            done(mImage, size);
+            emit done(mImage, size);
             LOG("Done");
         }
     }
@@ -308,13 +301,13 @@ void ThumbnailGenerator::run()
 
 void ThumbnailGenerator::cacheThumbnail()
 {
-    mImage.setText("Thumb::URI"          , mOriginalUri);
-    mImage.setText("Thumb::MTime"        , QString::number(mOriginalTime));
-    mImage.setText("Thumb::Size"         , QString::number(mOriginalFileSize));
-    mImage.setText("Thumb::Mimetype"     , mOriginalMimeType);
-    mImage.setText("Thumb::Image::Width" , QString::number(mOriginalWidth));
-    mImage.setText("Thumb::Image::Height", QString::number(mOriginalHeight));
-    mImage.setText("Software"            , QStringLiteral("Gwenview"));
+    mImage.setText(QStringLiteral("Thumb::URI")          , mOriginalUri);
+    mImage.setText(QStringLiteral("Thumb::MTime")        , QString::number(mOriginalTime));
+    mImage.setText(QStringLiteral("Thumb::Size")         , QString::number(mOriginalFileSize));
+    mImage.setText(QStringLiteral("Thumb::Mimetype")     , mOriginalMimeType);
+    mImage.setText(QStringLiteral("Thumb::Image::Width") , QString::number(mOriginalWidth));
+    mImage.setText(QStringLiteral("Thumb::Image::Height"), QString::number(mOriginalHeight));
+    mImage.setText(QStringLiteral("Software")            , QStringLiteral("Gwenview"));
 
     emit thumbnailReadyToBeCached(mThumbnailPath, mImage);
 }
