@@ -415,8 +415,8 @@ void DocumentTest::testSaveAs()
     QTest::qWait(100); // saved() is emitted asynchronously
     QCOMPARE(savedSpy.count(), 1);
     QVariantList args = savedSpy.takeFirst();
-    QCOMPARE(args.at(0).value<QUrl>(), url);
-    QCOMPARE(args.at(1).value<QUrl>(), destUrl);
+    QCOMPARE(args.at(0).toUrl(), url);
+    QCOMPARE(args.at(1).toUrl(), destUrl);
 
     QImage image("result.png", "png");
     QCOMPARE(doc->image(), image);
@@ -428,7 +428,7 @@ void DocumentTest::testSaveAs()
 
     QCOMPARE(documentChangedSpy.count(), 1);
     args = documentChangedSpy.takeFirst();
-    QCOMPARE(args.at(0).value<QUrl>(), destUrl);
+    QCOMPARE(args.at(0).toUrl(), destUrl);
 }
 
 void DocumentTest::testLosslessSave()
@@ -499,7 +499,7 @@ void DocumentTest::testModifyAndSaveAs()
     class TestOperation : public AbstractImageOperation
     {
     public:
-        void redo()
+        void redo() override
     {
             QImage image(10, 10, QImage::Format_ARGB32);
             image.fill(QColor(Qt::white).rgb());
@@ -532,7 +532,7 @@ void DocumentTest::testModifyAndSaveAs()
     QCOMPARE(lst.first(), url);
     QCOMPARE(documentChangedSpy.count(), 1);
     args = documentChangedSpy.takeFirst();
-    QCOMPARE(args.at(0).value<QUrl>(), url);
+    QCOMPARE(args.at(0).toUrl(), url);
 
     // Save it under a new name
     QUrl destUrl = urlForTestOutputFile("modify.png");
@@ -589,7 +589,7 @@ void DocumentTest::testMetaInfoBmp()
     Q_ASSERT(metaInfoUpdatedSpy.count() >= 1);
 
     QString value = doc->metaInfo()->getValueForKey("General.ImageSize");
-    QString expectedValue = QString("%1x%2").arg(width).arg(height);
+    QString expectedValue = QStringLiteral("%1x%2").arg(width).arg(height);
     QCOMPARE(value, expectedValue);
 }
 
@@ -676,7 +676,7 @@ public:
     {}
 
 protected:
-    virtual void doStart()
+    void doStart() override
     {
         *mStr += mCh;
         emitResult();
@@ -705,12 +705,12 @@ void DocumentTest::testJobQueue()
     QVERIFY(!doc->isBusy());
     QCOMPARE(spy.count(), 2);
     QVariantList row = spy.takeFirst();
-    QCOMPARE(row.at(0).value<QUrl>(), url);
+    QCOMPARE(row.at(0).toUrl(), url);
     QVERIFY(row.at(1).toBool());
     row = spy.takeFirst();
-    QCOMPARE(row.at(0).value<QUrl>(), url);
+    QCOMPARE(row.at(0).toUrl(), url);
     QVERIFY(!row.at(1).toBool());
-    QCOMPARE(str, QString("abc"));
+    QCOMPARE(str, QStringLiteral("abc"));
 }
 
 class TestCheckDocumentEditorJob : public DocumentJob
@@ -723,7 +723,7 @@ public:
     }
 
 protected:
-    virtual void doStart()
+    void doStart() override
     {
         document()->waitUntilLoaded();
         *mHasEditor = checkDocumentEditor() ? 1 : 0;
@@ -744,7 +744,7 @@ public:
         *mShowErrorMessageCalled = false;
     }
 
-    virtual void showErrorMessage()
+    void showErrorMessage() override
     {
         //qDebug();
         *mShowErrorMessageCalled = true;
@@ -795,7 +795,7 @@ void DocumentTest::testUndoStackPush()
     class SuccessOperation : public AbstractImageOperation
     {
     protected:
-        virtual void redo()
+        void redo() override
     {
             QMetaObject::invokeMethod(this, "finish", Qt::QueuedConnection, Q_ARG(bool, true));
         }
@@ -804,7 +804,7 @@ void DocumentTest::testUndoStackPush()
     class FailureOperation : public AbstractImageOperation
     {
     protected:
-        virtual void redo()
+        void redo() override
     {
             QMetaObject::invokeMethod(this, "finish", Qt::QueuedConnection, Q_ARG(bool, false));
         }
@@ -839,13 +839,13 @@ void DocumentTest::testUndoRedo()
         int mUndoCount = 0;
 
     protected:
-        virtual void redo()
+        void redo() override
         {
             mRedoCount++;
             finish(true);
         }
 
-        virtual void undo()
+        void undo() override
         {
             mUndoCount++;
             finish(true);
